/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 * @brief Timer example project with interrupt.
 * 
 * In this example TIMER interrupt is enabled. The TIMER interrupt handler will toggle a LED whenever
 * the TIMER counter is equal to a value of compare register CC[0] or compare register CC[[1]. CC[0] and
 * CC[1] register values can be adjusted to change the LED duty cycle. While waiting for TIMER interrupt
 * the CPU is put to sleep in the main loop with the __WFI command.
 */

#include <stdbool.h>
#include "nrf.h"
#include "nrf_gpio.h"

#define GPIO_TOGGLE_PIN              (8)       /*!< gpio pin to toggle after delay. Set to 18 if using Evaluation kit. */


void start_timer(void)
{		
  NRF_TIMER2->MODE = TIMER_MODE_MODE_Timer;  // Set the timer in Counter Mode
  NRF_TIMER2->TASKS_CLEAR = 1;               // clear the task first to be usable for later
	NRF_TIMER2->PRESCALER = 6;
	NRF_TIMER2->BITMODE = TIMER_BITMODE_BITMODE_16Bit;//0x01UL;										//Set counter to 16 bit resolution
	NRF_TIMER2->CC[0] = 25000;
	NRF_TIMER2->CC[1] = 5;
		
  // Enable interrupt on Timer 2
	NRF_TIMER2->INTENSET = (TIMER_INTENSET_COMPARE0_Enabled << TIMER_INTENSET_COMPARE0_Pos) | (TIMER_INTENSET_COMPARE1_Enabled << TIMER_INTENSET_COMPARE1_Pos);
  NVIC_EnableIRQ(TIMER2_IRQn);
		
  NRF_TIMER2->TASKS_START = 1;               // Start timer
}
		
/** Timer 2 peripheral interrupt handler.
 */
void TIMER2_IRQHandler(void)
{
	
	if ((NRF_TIMER2->EVENTS_COMPARE[1] != 0) && ((NRF_TIMER2->INTENSET & TIMER_INTENSET_COMPARE1_Msk) != 0))
  {
		NRF_TIMER2->EVENTS_COMPARE[1] = 0;
	
		nrf_gpio_pin_clear(GPIO_TOGGLE_PIN);
  }
	
  if ((NRF_TIMER2->EVENTS_COMPARE[0] != 0) && ((NRF_TIMER2->INTENSET & TIMER_INTENSET_COMPARE0_Msk) != 0))
  {
		NRF_TIMER2->EVENTS_COMPARE[0] = 0;
		
		nrf_gpio_pin_set(GPIO_TOGGLE_PIN);
  }
}

int main(void)
{
	nrf_gpio_port_dir_set(NRF_GPIO_PORT_SELECT_PORT1, NRF_GPIO_PORT_DIR_OUTPUT);

	start_timer();
	
	while(true) 
	{
		//Put CPU to sleep while waiting for interrupt
		__WFI();
	}
}
